@@ -324,7 +324,9 @@ def test_description_with_ref_link_to_reused_ref() -> None:
     """Same as "test_description_with_ref", but do not allow reusing references."""
     soup = _generate_case("description_with_ref", link_to_reused_ref=False)
 
-    _assert_descriptions(soup, ["We should see this", "inner description", "We should see this too"])
+    _assert_descriptions(
+        soup, ["We should see this", "inner description", "We should see this too", "inner description"]
+    )
 
 
 def test_with_examples() -> None:
@@ -337,22 +339,21 @@ def test_with_examples() -> None:
     examples_content = soup.find_all("div", class_="examples")
     examples_content_text = [ex.findChildren()[0].text for ex in examples_content]
     assert examples_content_text == [
-        '"Guido"',
-        '"BDFL"',
-        '"Van Rossum"',
-        "64",
+        '"Guido"\n',
+        '"BDFL"\n',
+        '"Van Rossum"\n',
+        "64\n",
         """{
     "birthplace": "Haarlem, Netherlands",
     "favorite_emoji": "🐍",
-    "motto": "Beautiful is better than ugly.\\\\nExplicit is better than implicit.\\\\nSimple is better than complex.\\\\nComplex is better than complicated.\\\\nFlat is better than nested.\\\\nSparse is better than dense.\\\\nReadability counts.\\\\nSpecial cases aren't special enough to break the rules.\\\\nAlthough practicality beats purity.\\\\nErrors should never pass silently.\\\\nUnless explicitly silenced.\\\\nIn the face of ambiguity, refuse the temptation to guess.\\\\nThere should be one-- and preferably only one --obvious way to do it.\\\\nAlthough that way may not be obvious at first unless you're Dutch.\\\\nNow is better than never.\\\\nAlthough never is often better than *right* now.\\\\nIf the implementation is hard to explain, it's a bad idea.\\\\nIf the implementation is easy to explain, it may be a good idea.\\\\nNamespaces are one honking great idea -- let's do more of those!"
-}""",
+    "motto": "Beautiful is better than ugly.\\\\nExplicit is better than implicit.\\\\nSimple is better than complex.\\\\nComplex is better than complicated.\\\\nFlat is better than nested.\\\\nSparse is better than dense.\\\\nReadability counts.\\\\nSpecial cases aren't special enough to break the rules.\\\\nAlthough practicality beats purity.\\\\nErrors should never pass silently.\\\\nUnless explicitly silenced.\\\\nIn the face of ambiguity, refuse the temptation to guess.\\\\nThere should be one-- and preferably only one --obvious way to do it.\\\\nAlthough that way may not be obvious at first unless you're Dutch.\\\\nNow is better than never.\\\\nAlthough never is often better than *right* now.\\\\nIf the implementation is hard to explain, it's a bad idea.\\\\nIf the implementation is easy to explain, it may be a good idea.\\\\nNamespaces are one honking great idea -- let\'s do more of those!"
+}\n""",
     ]
 
 
-@pytest.mark.parametrize("link_to_reused_ref", [True, False])
-def test_recursive(link_to_reused_ref: bool) -> None:
+def test_recursive() -> None:
     """Test a schema having a recursive definition"""
-    soup = _generate_case("recursive", link_to_reused_ref=link_to_reused_ref)
+    soup = _generate_case("recursive", link_to_reused_ref=True)
 
     _assert_descriptions(soup, ["A human being", "The children they had", "A human being"])
 
@@ -361,10 +362,9 @@ def test_recursive(link_to_reused_ref: bool) -> None:
     assert recursive_definition_link.text == "Same definition as person"
 
 
-@pytest.mark.parametrize("link_to_reused_ref", [True, False])
-def test_recursive_array(link_to_reused_ref: bool) -> None:
+def test_recursive_array() -> None:
     """Test a schema having a recursive definition pointing to array items"""
-    soup = _generate_case("recursive_array", link_to_reused_ref=link_to_reused_ref)
+    soup = _generate_case("recursive_array", link_to_reused_ref=True)
 
     _assert_descriptions(soup, ["A list of people", "A human being", "The children they had", "A human being"])
 
@@ -373,6 +373,12 @@ def test_recursive_array(link_to_reused_ref: bool) -> None:
     assert recursive_definition_link.text == "Same definition as person_items"
 
 
+def test_recursive_no_reuse() -> None:
+    """Test that disallowing reusing of references breaks creating schemas with recursive definitions"""
+    with pytest.raises(RecursionError):
+        _ = _generate_case("recursive", link_to_reused_ref=False)
+
+
 def test_pattern_properties() -> None:
     soup = _generate_case("pattern_properties")
 
